#
# spec file for package firebird
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define up_stage 0

Name:           firebird
Version:        3.0.7.33374
Release:        lp151.5.3.1
Summary:        Database system (common files)
License:        SUSE-IDPL-1.0 AND SUSE-IBPL-1.0
Group:          Productivity/Databases/Servers
URL:            https://www.firebirdsql.org/
# https://github.com/FirebirdSQL/firebird/releases/ - fetch and run firebird-clean-tar.sh
Source:         Firebird-%{version}-%{up_stage}.tar.xz
Source1:        README.SUSE
Source2:        50-server.conf
Source3:        firebird-clean-tar.sh
Source999:      baselibs.conf
BuildRequires:  autoconf >= 2.67
BuildRequires:  gcc-c++
BuildRequires:  libedit-devel
BuildRequires:  libicu-devel
BuildRequires:  libtommath-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  zlib-devel
Requires(pre):  pwdutils
Requires(pre):  %insserv_prereq

%if 0%{?suse_version} < 1130
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%endif

Patch1:         fbguard-allow-creating-a-guard-pidfile.patch
Patch2:         use-killproc-in-stop-branch-of-SuSE-init-script.patch
Patch3:         disable-xinetd-service-by-default.patch
Patch4:         add-pkgconfig-files.patch
Patch5:         Provide-sized-global-delete-operators-when-compiled-.patch
Patch6:         unicode-handle-new-SUSE-ICU-version-hack.patch
# work around problems with old g++
Patch91:        work-around-g-problem-in-SLE11.patch
Patch92:        use-C-98-on-SLE11.patch

%description
This package provides common files needed by both client and server
installations of Firebird RDBMS.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%prep
%setup -q -n Firebird-%{version}-%{up_stage}
# check for files with unclear licensing (bsc#763446)
if [ -d extern/SfIO ]; then
    echo "please repack the tarball without extern/SfIO directory (see bsc#763446)" >&2
    exit 1
fi
# --
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
# --
# work around a problem with old g++
%if 0%{?suse_version} < 1140
%patch91 -p1
%patch92 -p1
%endif

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="${CFLAGS} -fno-delete-null-pointer-checks"
./autogen.sh --prefix=%{_prefix} \
  --with-system-editline \
  --with-fbbin=%{_bindir} \
  --with-fbsbin=%{_sbindir} \
  --with-fbconf=%{_sysconfdir}/%{name} \
  --with-fblib=%{_libdir} \
  --with-fbinclude=%{_includedir} \
  --with-fbdoc=%{_docdir}/%{name} \
  --with-fbudf=%{_libdir}/%{name}/udf \
  --with-fbsample=%{_docdir}/%{name}/sample \
  --with-fbsample-db=%{_localstatedir}/lib/%{name}/sample \
  --with-fbhelp=%{_libdir}/%{name}/lib \
  --with-fbintl=%{_libdir}/%{name}/intl \
  --with-fbmisc=%{_datadir}/%{name}/misc \
  --with-fbsecure-db=%{_localstatedir}/lib/%{name}/secdb \
  --with-fbmsg=%{_libdir}/%{name}/lib \
  --with-fblog=%{_localstatedir}/log/%{name} \
  --with-fbglock=%{_localstatedir}/run/%{name} \
  --with-fbplugins=%{_libdir}/%{name}/plugins
make %{?_smp_mflags}
cd gen
make %{?_smp_mflags} -f Makefile.install buildRoot
chmod -R u+w buildroot%{_docdir}/%{name}
cat >>buildroot%{_sysconfdir}/%{name}/firebird.conf <<EOT

# allow additional config files
include \$(dir_conf)/firebird.conf.d/*.conf
EOT

%install
chmod u+rw,a+rx gen/buildroot/usr/include/firebird/impl
cp -r gen/buildroot/* %{buildroot}/
mkdir -p %{buildroot}%{_initddir}
install -m 755 gen/install/misc/firebird.init.d.suse \
  %{buildroot}%{_initddir}/firebird
mkdir -p %{buildroot}%{_libdir}/pkgconfig
cp -v gen/install/misc/*.pc %{buildroot}%{_libdir}/pkgconfig/
cd %{buildroot}
mkdir -p .%{_libdir}/%{name}/utils
mv -v .%{_sbindir}/*.sh .%{_libdir}/%{name}/utils/
mv -v .%{_sbindir}/fb_config .%{_libdir}/%{name}/utils/
rm -vf .%{_libdir}/libicu*.so
mv -vi .%{_bindir}/isql .%{_bindir}/isql-fb
mv -vi .%{_bindir}/gstat .%{_bindir}/gstat-fb
mv -vi .%{_includedir}/ibase.h .%{_includedir}/%{name}/
mv -vi .%{_includedir}/iberror.h .%{_includedir}/%{name}/
mv -vi .%{_includedir}/ib_util.h .%{_includedir}/%{name}/
rm -vf .%{_includedir}/*.h
chmod -R u+w .%{_docdir}/%{name}
rm -vf .%{_datadir}/%{name}/misc/firebird.init.*
rm -vf .%{_datadir}/%{name}/misc/rc.config.firebird
%if 0%{?suse_version} < 1500 || 0%{?is_opensuse}
mkdir -p .%{_sysconfdir}/xinetd.d
mv -v .%{_datadir}/%{name}/misc/firebird.xinetd \
  .%{_sysconfdir}/xinetd.d/%{name}
%endif
mv -v .%{_sysconfdir}/%{name}/README .%{_sysconfdir}/%{name}/WhatsNew \
  .%{_docdir}/%{name}/
mv -v .%{_sysconfdir}/%{name}/IDPLicense.txt .%{_docdir}/%{name}/
mv -v .%{_sysconfdir}/%{name}/IPLicense.txt .%{_docdir}/%{name}/
chmod -R go+rX .%{_datadir}/%{name}/misc
cp -vi %{SOURCE1} .%{_docdir}/%{name}/
mkdir -p .%{_sysconfdir}/%{name}/firebird.conf.d
cp -v %{SOURCE2} .%{_sysconfdir}/%{name}/firebird.conf.d/
mkdir -p srv/%{name}
ln -s %{_initddir}/firebird usr/sbin/rcfirebird

%files
%defattr(-,root,root)
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/firebird.conf
%dir %{_sysconfdir}/%{name}/firebird.conf.d
%dir %{_libdir}/%{name}
%dir %{_datadir}/%{name}
%{_libdir}/%{name}/intl
%{_libdir}/%{name}/lib
%{_libdir}/%{name}/plugins/libEngine12.so
%{_datadir}/%{name}/misc
%if 0%{?suse_version} >= 1500 && !0%{?is_opensuse}
%exclude %{_datadir}/%{name}/misc/firebird.xinetd
%endif
%{_docdir}/%{name}/IDPLicense.txt
%{_docdir}/%{name}/IPLicense.txt
%{_docdir}/%{name}/README.SUSE
%dir %{_localstatedir}/lib/%{name}
%dir %{_localstatedir}/lib/%{name}/secdb
%attr(0750,firebird,firebird) %{_localstatedir}/log/%{name}
%dir %attr(0750,firebird,firebird) /srv/firebird

%pre
getent group firebird >/dev/null || groupadd -r firebird || :
getent passwd firebird >/dev/null \
  || %{_sbindir}/useradd -r -g firebird -c 'Firebird SQL server' \
       -d /srv/firebird firebird \
  || :
exit 0

# ----------------------------------------------------------------------------

%package server
Summary:        Server files of Firebird RDBMS
Group:          Productivity/Databases/Servers
Requires:       %{name} = %{version}
Recommends:     %{name}-utils
# replaces these two from Leap 42.x and older
Provides:       firebird-classic = %{version}
Provides:       firebird-superserver = %{version}
Obsoletes:      firebird-classic < 3
Obsoletes:      firebird-superserver < 3

%description server
This package provides files needed to run Firebird RDBMS as a server.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files server
%defattr(-,root,root)
%{_sbindir}/fb_lock_print
%{_sbindir}/fbguard
%{_sbindir}/firebird
%{_sbindir}/rcfirebird
%config(noreplace) %{_sysconfdir}/%{name}/databases.conf
%config(noreplace) %{_sysconfdir}/%{name}/fbtrace.conf
%config(noreplace) %{_sysconfdir}/%{name}/plugins.conf
%config(noreplace) %{_sysconfdir}/%{name}/firebird.conf.d/50-server.conf
%if 0%{?suse_version} < 1500 || 0%{?is_opensuse}
%if 0%{?suse_version} >= 1500
%dir %{_sysconfdir}/xinetd.d
%endif
%config(noreplace) %{_sysconfdir}/xinetd.d/%{name}
%else
%{_datadir}/%{name}/misc/firebird.xinetd
%endif
%exclude %{_libdir}/%{name}/plugins/libEngine12.so
%{_libdir}/%{name}/plugins
%{_libdir}/%{name}/udf
%{_libdir}/%{name}/utils
%attr(0600,firebird,firebird) %config(noreplace) %{_localstatedir}/lib/%{name}/secdb/security3.fdb
%attr(755,root,root) %{_initddir}/firebird

%post server
%restart_on_update %{_initddir}/firebird

%preun server
%stop_on_removal %{_initddir}/firebird

%postun server
%restart_on_update %{_initddir}/firebird
%insserv_cleanup

# ----------------------------------------------------------------------------

%package utils
Summary:        Firebird RDBMS management utilities
Group:          Productivity/Databases/Servers
Requires:       %{name} = %{version}
# split out of firebird after 42.x
Provides:       %{name}-superserver:%{_bindir}/gbak

%description utils
This package provides for Firebird RDBMS management.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files utils
%defattr(-,root,root)
%{_bindir}/fbsvcmgr
%{_bindir}/fbtracemgr
%{_bindir}/gbak
%{_bindir}/gfix
%{_bindir}/gpre
%{_bindir}/gsec
%{_bindir}/gsplit
%{_bindir}/gstat-fb
%{_bindir}/isql-fb
%{_bindir}/nbackup
%{_bindir}/qli

# ----------------------------------------------------------------------------

%package -n libfbclient2
Summary:        Firebird RDBMS client library
Group:          System/Libraries
Requires:       %{name} >= 3.0
Requires:       libib_util
Provides:       libfbembed2_5 = %{version}
Obsoletes:      libfbembed2_5 < 3

%description -n libfbclient2
Shared client library for Firebird SQL server. Can be used both to
connect to remote servers and to access local databases in embedded
mode.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files -n libfbclient2
%defattr(-,root,root)
%{_libdir}/libfbclient.so.*

%post -n libfbclient2 -p /sbin/ldconfig

%postun -n libfbclient2
/sbin/ldconfig

# ----------------------------------------------------------------------------

%package -n libfbclient-devel
Summary:        Development files for Firebird RDBMS client library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libfbclient2 = %{version}
Suggests:       %{name}-examples
Provides:       libfbclient2-devel = %{version}
Obsoletes:      libfbclient2-devel < 3
Provides:       firebird-devel = %{version}
Obsoletes:      firebird-devel < 3
# temporary workaround for LibreOffice build
# once FB3 is in Factory, libreoffice buildrequires will be fixed
# and this can be removed
Provides:       libfbembed-devel

%description -n libfbclient-devel
This package is needed for development of client applications accessing
Firebird RDBMS.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files -n libfbclient-devel
%defattr(-,root,root)
%exclude %{_includedir}/%{name}/ib_util.h
%{_includedir}/%{name}
%{_libdir}/libfbclient.so
%{_libdir}/pkgconfig/fbclient.pc

# ----------------------------------------------------------------------------

%package -n libib_util
Summary:        Firebird RDBMS UDF support library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n libib_util
Library providing utility functions for Firebird RDBMS user defined
functions (UDF).

Note: this library may be also loaded via dlopen() by Engine12
plugin as it's also needed for embedded connections (as long as UDFs
are used).

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files -n libib_util
%defattr(-,root,root)
%{_libdir}/libib_util.so

%post -n libib_util -p /sbin/ldconfig

%postun -n libib_util
/sbin/ldconfig

# ----------------------------------------------------------------------------

%package -n libib_util-devel
Summary:        Development files for Firebird RDBMS
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libfbclient2 = %{version}
Requires:       libib_util = %{version}
Suggests:       %{name}-examples
Provides:       firebird-devel:%{_includedir}/firebird/ib_util.h

%description -n libib_util-devel
This package provides header files for libib_util, support library for
user defined functions (UDF) for Firebird RDBMS.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files -n libib_util-devel
%defattr(-,root,root)
%{_includedir}/%{name}/ib_util.h

# ----------------------------------------------------------------------------

%package doc
Summary:        Documentation for Firebird RDBMS
Group:          Documentation/Other
Requires:       %{name} = %{version}
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description doc
Documentation for Firebird RDBMS.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files doc
%defattr(-,root,root)
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/sample
%exclude %{_docdir}/%{name}/IDPLicense.txt
%exclude %{_docdir}/%{name}/IPLicense.txt
%exclude %{_docdir}/%{name}/README.SUSE

# ----------------------------------------------------------------------------

%package examples
Summary:        Example files for Firebird RDBMS
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description examples
This package provides an example database and API usage examples for
Firebird RDBMS.

Firebird is a relational database offering many ANSI SQL standard
features that runs on Linux, Windows, and a variety of Unix platforms.
Firebird offers excellent concurrency, high performance, and powerful
language support for stored procedures and triggers. It has been used
in production systems, under a variety of names, since 1981.


%files examples
%defattr(-,root,root)
%{_docdir}/%{name}/sample
%dir %{_localstatedir}/lib/%{name}/sample
%attr(0640,firebird,firebird) %{_localstatedir}/lib/%{name}/sample/*

# ----------------------------------------------------------------------------

%changelog
* Sat Oct 31 2020 Michal Kubeček <mkubecek@suse.cz>
- update to upstream version 3.0.7
  * better diagnostic for the 'Missing security context' error
    (CORE-6362)
  * disconnect from the security database when missing plugin data
    structures cause an error (CORE-6339)
  * multiple important bug fixes
* Sat Oct 17 2020 Michal Kubeček <mkubecek@suse.cz>
- update to upstream version 3.0.6
  * add better transaction control in isql (CORE-4933)
  * increase parse speed of long queries (CORE-6274)
  * improve performance when using SRP plugin (CORE-6237)
- refresh
  * work-around-g-problem-in-SLE11.patch
* Tue Jun 23 2020 Michal Kubecek <mkubecek@suse.cz>
- minor specfile cleanup
* Sun Jun 21 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.0.5:
  * Improve the engine providers compatibility across Firebird
    versions
  * Make it possible for the AuthClient plugin to access the
    authentication block from DPB
  * Implement option to restore compressed .nbk files without
    explicitly decompressing them
* Wed Nov 21 2018 mkubecek@suse.cz
- update to upstream version 3.0.4
  * add support for SRP authentication using SHA-256
  * ODS (database file format) version raised to 12.2 on some
    architectures (including i586, not x86_64); new version will be
    able to open existing ODS 12.0 created on the same architecture
    but for database transfer between architectures, backup/restore
    is always recommended
  * context variables WIRE_COMPRESSED and WIRE_ENCRYPTED were added
    to the SYSTEM namespace to report compression and encryption
    status, respectively, of the current connection (CORE-5913)
  * enhanced reporting of errors when dynamic library fails to load
    (CORE-5908)
  * include funciton name when UDF causes "Arithmetic exception,
    numeric overflow, or string truncation" error (CORE-5876)
  * context variables LOCALTIME and LOCALTIMESTAMP (synonyms for
    CURRENT_TIME and CURRENT_TIMESTAMP) for compatibility with 4.0
    (CORE-5853)
  * read-only restriction for system tables was relaxed to permit
    CREATE, ALTER and DROP operations on their indexes (CORE-5746)
  * fix unauthorized BLOB access vulnerability (CORE-5801)
  * for a full list of bugfixes and improvements see
    http://www.firebirdsql.org/file/documentation/release_notes/html/en/3_0/rnfb30-general.html#rnfb30-general-v304
- drop patches included in new upstream release:
  Make-it-build-with-icu60.patch
  An-attempt-to-fix-CORE-5764-need-feedback-on-snapsho.patch
  Fixed-a-code-somewhy-accepted-by-gcc6.patch
- refresh patches:
  work-around-g-problem-in-SLE11.patch
  use-C-98-on-SLE11.patch
* Wed Jul  4 2018 mkubecek@suse.cz
- replace unicode-handle-the-ICU-version-hack-from-SuSE.patch
  with more general upstream solution:
  * An-attempt-to-fix-CORE-5764-need-feedback-on-snapsho.patch
  * Fixed-a-code-somewhy-accepted-by-gcc6.patch
- unicode-handle-new-SUSE-ICU-version-hack.patch:
  search also for "suse%%d.%%d" soname pattern to fix build after
  upcoming ICU update (bsc#1095425)
* Wed Mar 28 2018 mkubecek@suse.cz
- move firebitd.xinetd back to firebird-server subpackage on SLE15
- provide /etc/xinetd.d directory on Tumbleweed and Leap 15.0 as
  xinetd is no longer guaranteed to be present there; this solution
  (suggested by Dimstar) is less painful than either having
  firebird-server depend on xinetd or splitting a new subpackage
  firebird-server-classic.
* Fri Mar 23 2018 mkubecek@suse.cz
- patch xinetd config file unconditionally; previous change would
  result in unpatched xinetd config file installed on Tumbleweed
  so that the service would be enabled by default and firebird
  binary run as root
* Thu Mar 22 2018 fcrozat@suse.com
- Move xinetd file to /usr/share/misc/firebird on SLE15/Leap15/TW
  (bsc#1084459).
- Do no ship xinetd file on SLE15 (bsc#1084459).
* Sat Mar  3 2018 mkubecek@suse.cz
- update to upstream version 3.0.3
  * fix conflicting constants; programs using * fb_info_crypt_state
    constant must be recompiled
  * provide crypto key name via fb_info_crypt_key item in
    Attachment::getInfo()
  * improve handling of concurrent ALTER DATABASE statements
  * make sure ORDER BY with equivalent expressions are equivalent
    and use the same plan
  * avoid serialization of isc_attach_database calls issued by
    EXECUTE STATEMENT
  * show date and time of analysis in gstat output
  * show database info in sweep error message
  * provide compression details and encryption status of the
    connection in Attachment::getInfo() API call
  * fix RDB$RELATION_TYPE when restoring ODS < 11.1 database
  * the optimizer can now estimate the actual record compression
    ratio
  * various performance improvements
  * various bug fixes, for a list, see release notes at
    http://www.firebirdsql.org/file/documentation/release_notes/html/en/3_0/rnfb30-bug.html
- drop patches included in new upstream version:
  Backported-fix-for-CORE-5549-Errors-building-running.patch
  Backported-fix-for-CORE-5562-Firebird-crashes-when-U.patch
  Fixed-CORE-5567-Direct-system-table-modifications-ar.patch
  Make-the-generated-code-compatible-with-gcc-6-in-C-1.patch
  Workaround-for-CORE-5566-Server-crashes-while-restor.patch
- unicode-handle-the-ICU-version-hack-from-SuSE.patch:
  rework to handle ICU >= 60 (as many versions as upstream)
- drop firebird-icu60.patch
  obsoleted by update of the unicode patch
- Make-it-build-with-icu60.patch
  upstream post-3.0.3 commit for ICU >= 59 compatibility
- use-C-98-on-SLE11.patch
  compatibility patch for SLE11 where gcc 4.3 does not support
  - stc=gnu++03 (applied only on SLE11)
* Thu Jan  4 2018 dimstar@opensuse.org
- Add firebird-icu60.patch: Fix build with icu 60.x.
* Fri Jun 30 2017 mkubecek@suse.cz
- update to upstream version 3.0.2
  * allow to to filter out info and warnings from the trace log
  * enhance control capability when sharing the database crypt key
    between Superserver attachments
  * the physical numbers of frequently used data pages are now
    cached to reduce the number of fetches of pointer pages
  * in SuperServer mode, read-only transaction will no longer force
    write the Header\TIP page content to disk immediately after
    a change
  * make the database name available to an encryption plug-in
  * enable nesting of keys in a plug-in configuration
  * build linux code with --enable-binreloc
  * trace: provide a filter to INCLUDE / EXCLUDE errors by their
    mnemonical names
  * port for ancient Motorola 68000 CPU platform
  * allow SELECT expressions as valid operands for the BETWEEN
    predicate
  * many bug fixes; for a list, see
    https://www.firebirdsql.org/file/documentation/release_notes/html/en/3_0/rnfb30-bug.html#bug-302
- Backported-fix-for-CORE-5474-Restrict-UDF-is-not-eff.patch:
  drop (included in 3.0.2)
- Backported-fix-for-CORE-5549-Errors-building-running.patch:
  fix errors when building/running on non-SSE CPU (CORE-5549)
- Backported-fix-for-CORE-5562-Firebird-crashes-when-U.patch:
  fix crash on frequent load/unload of UDF (CORE-5562)
- Workaround-for-CORE-5566-Server-crashes-while-restor.patch:
  workaround for server crash when restoring a backup while shadow
  file already exists (CORE-5566)
- Fixed-CORE-5567-Direct-system-table-modifications-ar.patch:
  fix the possibility to directly modivy system tables (CORE-5567)
- drop "--disable-binreloc", no longer needed
- add a check to fail in prep phase if extern/SfIO wasn't removed
  (bsc#763446)
* Sat Feb 18 2017 kukuk@suse.de
- Add missing insserv PreReq
* Tue Feb  7 2017 mkubecek@suse.cz
- Backported-fix-for-CORE-5474-Restrict-UDF-is-not-eff.patch
  security vulnerability fix for bypassing 'Restrict UDF' value of
  UdfAccess config directive (bsc#1023990)
* Thu Sep 29 2016 mkubecek@suse.cz
- update to upstream version 3.0.1
  * an assertion could occur in createDatabase() when doing the
    overwrite check (CORE-5339)
  * a database could suffer partial corruption in the "use all
    space" (no-reserve) mode (CORE-5329)
  * trying to encrypt a database in the absence of the the
    appropriate key could corrupt it (CORE-5292)
  * a database could get decrypted after changing a couple of bytes
    in the database header without 'agreement' from the crypt
    plug-in (CORE-5213)
  * access violation from certain UDFs would cause the server to
    crash (CORE-5234)
  * a segfault could occur when op_que_events was used on a port
    that was not prepared for events processing (CORE-5335)
  * a segfault could occur if an attachment was closed while
    requests were still open
  * for the full list of bugs fixed, se the release notes at
    http://www.firebirdsql.org/file/documentation/release_notes/html/en/3_0/rnfb30-bug.html#bug-301
  * the statement CREATE OR ALTER USER SYSDBA PASSWORD <password>
    can now be used to initialize an empty securityN.fdb security
    database (improvement CORE-5266)
  * nesting of keys in a plug-in configuration was enabled
    (improvement CORE-5257)
  * line and column numbers (location context) are now provided for
    runtime errors raised inside EXECUTE BLOCK (improvement
    CORE-5216)
  * gbak now returns a non-zero result code when restore fails on
    creating and activating a deferred user index (CORE-5201)
  * implicit conversion between Boolean and string is now done
    automatically when a string for 'true' or 'false' is used as a
    value in an expression (CORE-5167)
- drop patches merged present in new upstream release:
  allow-creating-buildRoot-as-non-root-user.patch
  Allow-to-enforce-IPv4-or-IPv6-in-URL-like-connection.patch
  Fix-locking-on-big-endian-architectures.patch
- update to current code:
  work-around-g-problem-in-SLE11.patch
* Wed Jun 29 2016 mkubecek@suse.cz
- add fake "Provides: libfbembed-devel" to libfbclient-devel
  subpackage; this is a temporary workaround to allow LibreOffice
  build both before and after firebird is upgraded to verison 3.0
  in Factory; once FB3 is in Factory, LibreOffice BuildRequires
  can be updated to libfbclient-devel (based on %%suse_version) and
  this hack can be dropped
* Tue May 31 2016 mkubecek@suse.cz
- move libEnginge12.so and intl/ into firebird package as these
  are also needed by embedded connections
- include /etc/firebird/firebird.conf.d/*.conf into configuration
- move the directive restricting DatabaseAccess to /srv/firebird
  into a separate config file in firebird-server subpackage so
  that it doesn't affect embedded-only installs
- do-not-use-DatabaseAccess-Full-in-default-config.patch:
  replaced by 50-server.conf
- fix Group tag for libfbclient2 and libib_util subpackages
- improve libib_util subpackage description
* Wed May 18 2016 mkubecek@suse.cz
- libfbclient-devel cannot be used as a direct replacement for
  libfbembed-devel so it's better to stop pretending so
- some packages have (unnecessary) explicit build requirement for
  firebird-devel whose contents was merged into libfbclient-devel;
  add corresponding Provides and Obsoletes
* Wed May 11 2016 mkubecek@suse.cz
- Fix-locking-on-big-endian-architectures.patch:
  fix broken code (and failed build) on big endian architectures
  (CORE-5232)
- explicitely require autoconf 2.67 or newer for build
* Wed May 11 2016 mkubecek@suse.cz
- upgrade to upstream version 3.0.0 (final)
  * one executable for all modes => drop firebird-classic package
  * true SMP support in SuperServer
  * new object oriented C++ API
  * per-database config files
  * increased limits
  * support multiple security databases
  * boolean type
  * SQL packages
  * DDL triggers
  * window functions
  * statistical functions
  * scrollable cursors
  * IPv6 support
- reorganize subpackages:
  * firebird: only common files needed for both client and server
  * firebird-server: server installation
  * libfbclient2: client library
  * firebird-utils: management utilities
  * libib_util: libib_util library (utility functions for UDF)
  * firebird-doc: documentation
  * firebird-examples: API examples
  * libfbclient-devel: devel files for libfbclient2
  * libib_util-devel: devel files for libib_util
- delete patches obsoleted by version upgrade:
  * Added-check-for-failed-fork-system-call.patch
  * Apply-Partial-patch-for-C-11-compilation-of-the-Fire.patch
  * Backported-fix-for-CORE-4785-Bad-packet-of-op_execut.patch
  * Backported-fix-for-CORE-4788-Superclassic-server-han.patch
  * Fixed-CORE-3431-ISQL-pads-UTF-8-data-incorrectly.patch
  * Fixed-s-tandalone-switch-in-posix-server.patch
  * isql-fix-buffer-overflow-when-set-width-sets-bigger-.patch
  * isql-fix-output-if-charset-is-different-from-locale.patch
  * Libreoffice-patch-C-11-new-delete-replacement-functi.patch
- delete add-experimental-support-for-m68k-architecture.patch
  architecture specific settings are managed in a different way
  in 3.0 so that this would need a complete rewrite; as this
  has little chance to get upstreamed and I doubt anyone plans
  to actually run Firebird 3.0 on openSUSE on m68k, let's just
  drop it
- update remaining patches:
  * add-pkgconfig-files.patch
  * allow-creating-buildRoot-as-non-root-user.patch
  * disable-xinetd-service-by-default.patch
  * do-not-use-DatabaseAccess-Full-in-default-config.patch
  * fbguard-allow-creating-a-guard-pidfile.patch
  * use-killproc-in-stop-branch-of-SuSE-init-script.patch
- new patches (from post-3.0 development):
  * unicode-handle-the-ICU-version-hack-from-SuSE.patch
    compatibility with SUSE ICU versioning hack
  * Make-the-generated-code-compatible-with-gcc-6-in-C-1.patch:
    gcc6 compatibility
  * Provide-sized-global-delete-operators-when-compiled-.patch:
    gcc6 compatibility
  * Allow-to-enforce-IPv4-or-IPv6-in-URL-like-connection.patch:
    implement "inet4" and "inet6" protocols for URL-like connection
    strings to enforce IPv4 or IPv6
  * work-around-g-problem-in-SLE11.patch:
    work around a bug in old g++ (needed for SLE11 build)
- build with -fno-delete-null-pointer-checks
- specfile cleanup
* Fri Feb 26 2016 rguenther@suse.com
- Build with -std=gnu++98 -fno-lifetime-dse for GCC 5+ to avoid
  issues with the old C++ code-base and its undefined behavior.  [bnc#964466]
* Mon Jul 27 2015 mkubecek@suse.cz
- fix libfbembed package name in baselibs.conf so that the
  libfbembed2_5-32bit is built
* Mon Jul 27 2015 mkubecek@suse.cz
- upgrade to upstream version 2.5.4 (final)
  * CORE-4558: SuperServer dies when client is disconnected
    abnormally during the index navigational scan
  * CORE-4676: Crash on unexpected client disconnection with opened
    transaction
  * CORE-4075: Server bugchecks or crashes on exception in
    calculated index
  * CORE-4624: Firebird handles ':' characters in mount table
    entries invalid
- Backported-fix-for-CORE-4788-Superclassic-server-han.patch:
  CORE-4788: Superclassic server hangs when receiving network
  packet
- Backported-fix-for-CORE-4785-Bad-packet-of-op_execut.patch:
  CORE-4785: Bad packet of op_execute kills the server
- Fixed-s-tandalone-switch-in-posix-server.patch:
  fix -s(tandalone) switch in posix server
- Added-check-for-failed-fork-system-call.patch:
  add check for failed fork() system call
- Apply-Partial-patch-for-C-11-compilation-of-the-Fire.patch:
  Libreoffice-patch-C-11-new-delete-replacement-functi.patch:
  two patches from LibreOffice fixing C++11 build
* Sun Dec  7 2014 mkubecek@suse.cz
- upgrade to upstream version 2.5.4.26821
  * server crash by malformed packet (bnc#908127, CORE-4029,
    CORE-4030)
  * various functional fixes
- removed patches merged into upstream:
  * Firebird-2.5.2.26539-0-fix-bashisms.patch:
  * aarch64-support.patch
  * firebird-2.5.2-CORE-4058.patch
  * firebird-2.5.2-icu49.patch
  * firebird-2.5.2-runlevel.patch
  * firebird-fix-unsigned-char.diff
  * firebird-s390x-fix_libdir.patch
  * ppc64-libdir.patch
- replace remaining patches by git based ones:
  * firebird-2.5.1-chown.patch
  - > allow-creating-buildRoot-as-non-root-user.patch
  * firebird-2.5.1-config.patch
  - > do-not-use-DatabaseAccess-Full-in-default-config.patch
  * firebird-2.5.1-disable.patch
  - > disable-xinetd-service-by-default.patch
  * firebird-2.5.2-gpidfile.patch
  - > fbguard-allow-creating-a-guard-pidfile.patch
  * firebird-2.5.2-init.patch
  - > use-killproc-in-stop-branch-of-SuSE-init-script.patch
    (remaining part not upstreamed)
  * firebird-2.5.2-isqlalign.patch
  - > Fixed-CORE-3431-ISQL-pads-UTF-8-data-incorrectly.patch
  * firebird-2.5.2-isqllocale.patch
  - > isql-fix-output-if-charset-is-different-from-locale.patch
  * firebird-2.5.2-isqlwidth.patch
  - > isql-fix-buffer-overflow-when-set-width-sets-bigger-.patch
  * firebird-2.5.2-pkgconfig.patch
  - > add-pkgconfig-files.patch
  * m68k-support.patch
  - > add-experimental-support-for-m68k-architecture.patch
- use xz compressed tarball
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashisms in scripts
- add patches:
  * Firebird-2.5.2.26539-0-fix-bashisms.patch
* Sat Jul  5 2014 coolo@suse.com
- install init script as executable
- fix the script
* Mon Feb 17 2014 ro@suse.de
- firebird-s390x-fix_libdir.patch: s390x uses lib64
* Tue Dec 17 2013 schwab@suse.de
- m68k-support.patch: add support for m68k
* Thu Dec  5 2013 mls@suse.de
- adapt for ppc64le
* Wed Aug 21 2013 fridrich.strba@suse.com
- firebird-2.5.2-pkgconfig.patch:
  fix fbembed.pc file to link with -lfbembed instead of -lfbclient
* Sun Jun  2 2013 mkubecek@suse.cz
- resolve file conflicts between packages
  * add explicit mutual conflict between -superserver and -classic
  * remove fbguard from -classic (it is shared between SS and SC)
* Fri Apr 12 2013 mkubecek@suse.cz
- config-guess-sub-update.patch:
  remove; attempt to patch these files would break build from
  subversion snapshots; remove both files instead and let
  libtoolize provide its own version
- reorder patches to keep the isql column alignment feature last
* Mon Apr  8 2013 schwab@suse.de
- firebird-fix-unsigned-char.diff:
  Compile with -fsigned-char
* Mon Apr  8 2013 matz@suse.de
- firebird-fix-unsigned-char.diff:
  fix for architectures where char is unsigned (aarch64 in this
  case, but applies everywhere)
- aarch64-support.patch:
  aarch64 doesn't need RISC_ALIGNMENT
* Sun Mar 24 2013 schwab@suse.de
- config-guess-sub-update.patch: update config.guess/sub for aarch64
- aarch64-support.patch: add support for aarch64
* Fri Mar  8 2013 mkubecek@suse.cz
- firebird-CORE-4058.patch:
  fix remote stack overflow (bnc#808268, CVE-2013-2492)
* Fri Jan 25 2013 coolo@suse.com
- fix license string
* Sun Nov 11 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26539 (2.5.2 final)
  * Optimizer level solution for CORE-2790/CORE-3449
  * CORE-2666: Make it possible to use API to do remote
    backups/restores
  * backup state lock should be released at latch timeout, else
    lock state accounting becomes inconsistent
  * CORE-3873: Server crashes while switching to the shadow if the
    disk I/O fault happens while flushing the cache
  * CORE-3860: Trace API: Faulty database filter crashes server
  * CORE-3875: GBak does not check correctly parameters and backups
    random database with -B ":"
  * CORE-3879: Make fb_lock_print a bit more handy
  * CORE-3656: Support for sweep information in Trace API
  * CORE-2668: Write note into log when automatic sweep is started
  * Enabled per-table runtime stats for sweeper (necessary for
    CORE-3656)
  * CORE-3884: Server crashes on preparing empty query when trace
    is enabled
  * CORE-3238: Makes GEN_UUID return a compliant RFC-4122 binary
    UUID
  * CORE-3887: CHAR_TO_UUID and UUID_TO_CHAR works different in
    big/little endian architectures - problem similar to CORE-2898
  * CORE-3895: High memory usage when PSQL code SELECT's from
    stored procedure which modified some data
  * Fixed the server crash in Stack::assign()
  * CORE-3902: Derived fields may not be optimized via an index
  * Fixed the broken (working as no-op) sweep in SuperServer
  * Use better name from trunk for CORE-3911
  * Restored the ODS level compatibility with v2.5.1 index keys,
    while using the "old good" index key format in new indices. It
    allows to claim that CORE-3675 and CORE-3853 are fixed (after
    migration via backup/restore) but still operate almost
    correctly with keys created in v2.5.1.
  * CORE-3912: segfault in superclassic
  * Better diagnostic (CORE-3786)
- firebird-2.5.2-icu49.patch:
  fix broken unicode collations (bnc#789171, CORE-3946)
* Wed Jul 25 2012 dvaleev@suse.com
- add libatomic-ops-devel on non x86 arches
- set libdir on powerpc correctly
* Sun Jul 22 2012 mkubecek@suse.cz
- firebird-2.5.2-runlevel.patch:
  don't start the daemon in runlevel 2
- add README.SUSE
* Wed Jun  6 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.25494
  * Rolled back the ODS level solution for CORE-2709 as it causes
    cross-version compatibility issues (CORE-3853) as well as
    functional regressions (CORE-3675). Another solution is likely
    to be committed instead.
  * CORE-3769: The message 'Unknown tag (4) in isc_svc_query()
    results' appears when fbtracemgr is interrupted by Ctrl-C
* Sun Jun  3 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.25492
  * CORE-3855: Blobs, inserted into GLOBAL TEMPORARY TABLE ON
    COMMIT DELETE ROWS, could be placed into newly allocated
    pages even if there is enough free place on some existing
    data page
  * isql: fix output if charset is different from locale
  * Backported fix of timed semaphores in 32-bit build
- firebird-2.5.2-isqlalign.patch:
  refresh
- firebird-2.5.2-isqllocale.patch:
  backported isql fix of output if locale different from charset
- firebird-2.5.2-isqlwidth.patch:
  backported fix for buffer overflow in isql if column width set
  wider that its natural size
* Fri May 25 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.25488
  * CORE-3611: Wrong data while retrieving from CTEs (or derived
    tables) with same column names
  * CORE-3557: AV in engine when preparing query against dropping
    table (a post-fix)
  * add interpreter specification to generated scripts
  * fix broken isql history with libedit 3.0
  * CORE-3612: send errors to stderr
- firebird-2.5.1-shebang.patch:
  delete (committed to upstream)
- remove extern/SfIO from the source tarball: while it is probably
  covered by an open source license (EPL), the file stdio.h itself
  contains only an unfriendly copyright notice without any
  reference to the license; as it is needed only on Solaris, it
  seems easier to simply remove it
- use standardized tags for licence
* Fri May 18 2012 mkubecek@suse.cz
- spec file formatting
- add copyright to spec file
* Fri May 18 2012 mkubecek@suse.cz
- Switching to new Firebird version (2.5) and spec file. This
  obsoletes the previous changes file from version 2.1.
* Mon May 14 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.25481
  * CORE-3539: TRACE: add ability for logging ERRORs that occur in
    runtime (lock conflicts, PK/UK/FK violations et al)
  * Trace errors raised by failed ON TRANSACTION ROLLBACK and ON
    DISCONNECT triggers
  * CORE-3598: TRACE: add statistics of actions that were after
    transaction finished
  * CORE-3814: SuperClassic server crashes when performing a
    database shutdown (FW=OFF)
  * fix regression introduced by patch for CORE-3777
  * CORE-3844: Validation not detects one specific case of index
    corruption
  * CORE-3841: Corrupted database after inserting rows
  * CORE-3839: Values disappearing from index
  * CORE-3845 : Interruption of 'heavy query' leads to 0 ms (zero
    duration) in it`s statistics in trace log
* Tue May  8 2012 mkubecek@suse.cz
- firebird-2.5.2-isqlalign.patch:
  replace locale based patch with backport from firebird 3.0
- firebird-2.5.2-gpidfile.patch:
  allow creating a pidfile for fbguard as well
- firebird-2.5.2-init.patch:
  use killproc and guard pidfile for "stop" branch
* Wed May  2 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.25472
  * CORE-3819: Wrong service name to port address resolution in
    database connection string
  * CORE-3825: If an autocommit transaction (i.e. transaction
    started with isc_tpb_autocommit option) run DDL using EXECUTE
    STATEMENT it will produce a bugcheck 287 (Too many savepoints)
  * Make the conf. parameter DummyPacketInterval more accurate
  * CORE-3834: Usage of a NATURAL JOIN with a derived table crashes
    the server
- temporary fix for "stop" branch of init script
* Mon Apr 16 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26467
  * CORE-3806: Wrong data returned if a sub-query or a computed
    field refers to the base table in the ORDER BY clause
  * CORE-3807: Error "Invalid expression in the select list" can be
    unexpectedly raised if a string literal is used inside a GROUP
    BY clause in a multi-byte connection
  * CORE-3686: Incorrect (zero) values are reported for "acquire
    blocks" and "mutex wait" counters in the fb_lock_print output
  * CORE-3810 : isql: zero divide + coredump when use "-pag 0"
    command switch & set heading on inside .sql script
  * Rolled back the optimization committed recently due to the
    found regressions
  * CORE-3812 : Connection lost to database during massive dropping
    and altering primary keys of tables
  * Do not ignore possible OS level errors even if they seem
    unlikely to happen
* Mon Apr  2 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26456
  * CORE-2286: Selecting from MON$CALL_STACK within a Trigger or SP
    sometimes return 0 rows
  * CORE-3569: CHAR(32767) present in XSQLVAR with length 32765
  * CORE-3195: Concatenation to CHAR(32766/7) impossible
  * CORE-3625: MON$IO_STATS doesn't report page writes performed
    asynchronously (at the AST level)
  * CORE-3092: ROW_COUNT is not cleared before the singleton INSERT
    statement
  * CORE-1992: bad BLR -- invalid stream for union select
  * untracked AV due to CORE-3649
  * Undo patch for CORE-3468
  * CORE-3791: Performance degrades when actively working with
    databases bigger than the available RAM amount
  * CORE-3770: fbtracemgr loads CPU up to ~55%% when no activity is
    present
  * CORE-3799: with caller privileges option don't work with
    autonomous transaction option
  * CORE-3801: Warnings could be put twice in status-vector
  * CORE-3802: Firebird runs out of memory while restoring database
    backup
* Mon Mar 12 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26436
  * CORE-2457: UNICODE_CI internal gds software consistency
    check
  * CORE-3762: gsec returns 0 return code on some errors
  * CORE-3649: gbak deletes backup file even if error happens
    when it's already successfully closed
  * CORE-3777: Conversion error from string when using GROUP BY
  * CORE-3721: Multiuser server startup (/etc/init.d) script
    picks up the ISC_ variables if set
- remove dependency of firebird-devel on firebird
* Wed Feb 29 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26429
  * CORE-3761: Conversion error when using a blob as an argument
    for the EXCEPTION statement
  * CORE-3778: AV at connection shutdown
  * CORE-1997: Broken foreign key handling for multi-segmented
    index using multi-level collations
  * CORE-2457: UNICODE_CI internal gds software consistency check
* Wed Feb 15 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26425
  * CORE-3750: Error increasing limits on posix
* Mon Jan 30 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26424
  * CORE-3732: Segfault when closing attachment to database
  * CORE-3730: isc_dsql_exec_immed2() loses input parameter value with
    RETURNING clause
  * CORE-3733: GBAK fails to fix system generators while restoring
  * CORE-3736: WITH LOCK clause is allowed for users with read-only
    rights on some table, thus blocking others from updating this table
  * Stop db triggers in qli
- declare BuildRoot only when needed (< 1130)
- define version in one place rather than two
* Mon Jan 16 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26417
  * add system indices to avoid full table scans on system tables
  * CORE-3722: IS NOT DISTINCT FROM NULL doesn't use index
  * CORE-3727: Support C preprocessor flags in firebird build system
  * CORE-3599: Don't allow to drop RDB$ADMIN role
- removed obsolete firebird-2.5.2-libs.patch (in upstream now)
* Mon Jan  2 2012 mkubecek@suse.cz
- update to upstream version 2.5.2.26411
  * CORE-3862: Multiple update installs can cause problems
  * CORE-3697: String truncation error when selecting from a VIEW with
    UNION inside
  * CORE-3683: Wrong results if the recursive query contains an embedded
    GROUP BY clause
  * CORE-3671: JVM Access Violation when using Firebird Embedded
  * CORE-3238: Make GEN_UUID return a compliant RFC-4122 binary UUID
    and introduce CHAR_TO_UUID2 and UUID_TO_CHAR2 to convert UUIDs
    from/to string also complying with the RFC
  * CORE-3677: Stop utilities to export entrypoints
  * CORE-3646: Segmentation fault in Linux
  * CORE-3658: FBSVCMGR connects to server as OS user name rather than
    value of ISC_USER environment variable
* Wed Dec 14 2011 mkubecek@suse.cz
- update to upstream version 2.5.2.26397
  * CORE-3490: Concurrency problem when using named cursors
  * CORE-3690: Wrong warning message for ambiguous query
  * CORE-3680: EXECUTE BLOCK statement and ISC_DSQL_EXECUTE2() problem
  * CORE-927: Grants don't work for procedures used inside views
  * CORE-3692: Cannot drop a NOT NULL constraint on a field
    participating in the UNIQUE constraint
  * CORE-3601 - Incorrect TEXT BLOB charset transliteration on VIEW with
    trigger
- add libtool and pkg-config to BuildRequires
* Tue Nov 29 2011 mkubecek@suse.cz
- fixed include directory in pkg-config files
- set --prefix to /usr (shouldn't influence anything anyway)
* Mon Nov 28 2011 mkubecek@suse.cz
- provide pkg-config files for libfbclient and libfbembed
* Thu Nov 10 2011 mkubecek@suse.cz
- update to upstream version 2.5.2.26389
  * CORE-3646: Segmentation fault in multi-threaded program when using
    2.5.x client library on Linux
  * CORE-3650: Recreation of collation leads to FB "death"
  * CORE-3557: AV in engine when preparing query against dropping table
  * CORE-3579: Can't drop table when computed field depends on later
  * created another field
* Mon Oct 31 2011 mkubecek@suse.cz
- update to upstream version 2.5.2.26386
  * CORE-3636: Firebird 2.5.1 server crashes with Trace API
  * CORE-3631: Duplicate records with NULLs checked incorrectly
  * CORE-3627: Server crashes with access violation when inserting
    row into table with unique index
  * CORE-3600: temp files fb_query_xxxx remains after ISQL has been
    closed
  * CORE-3612: gfix-related services may loose error value in status
    vector in isc_service_start()
  * CORE-3610: Can insert DUPLICATE keys in UNIQUE index
* Tue Oct 18 2011 mkubecek@suse.cz
- compatibility with upstream tarball
* Fri Sep 30 2011 mkubecek@suse.cz
- fixes in init script, removed unneeded patch
* Thu Sep 29 2011 mkubecek@suse.cz
- fix baselibs.conf (libib_util.so moved to firebird)
* Thu Sep 29 2011 mkubecek@suse.cz
- add /srv/firebird directory
- restrict DatabaseAccess to /srv/firebird in default configuration
- move libib_util back to main server package (it depends on it)
- mark xinetd config file as config
- build with system editline
- don't fail install/upgrade if user or group creation fails
- rename isql and gstat to avoid conflict with other packages
* Tue Sep 27 2011 mkubecek@suse.cz
- common firebird-devel for header files and libib_util.so
- separate firebird-superserver package
- separate firebird-classic package
- build firebird-doc as noarch if possible (suse_version > 1110)
- restart on update (in postun)
- remove full version from patch names
- disable xinetd service by default
- move misc to _datadir
* Mon Sep 26 2011 mkubecek@suse.cz
- moved to BuildService
- removed %%debug_package
- build libfbclient2-32bit
- move libib_util.so to main package
- restart on update
- fixed typo init init script
* Mon Sep 19 2011 mike@mk-sys.cz
- update to 2.5.1.26358
* Fri Jun 24 2011 mike@mk-sys.cz
- update to 2.5.1.26319
* Wed May 25 2011 mike@mk-sys.cz
- update to 2.5.1.26285
- remove init scripts for other distributions
- simplify user/group creation
* Tue May 17 2011 mike@mk-sys.cz
- update to 2.5.1.26279
- compile against system ICU
- shared libraries moved into a subpackage
- create /var/run/firebird in init script
- add Short-Description into the init script
- fixed interpreter specification in support scripts
- full path tu useradd and groupadd in pre-install script
* Sat Mar 19 2011 mike@mk-sys.cz
- update to 2.5.1.26239
* Mon Jan 17 2011 mike@mk-sys.cz
- update to 2.5.0.26179
* Sun Nov  7 2010 mike@mk-sys.cz
- add useradd and groupadd to dependencies
* Fri Oct 15 2010 mike@mk-sys.cz
- update to 2.5.0.26098 (2.5.0 Release)
* Wed Aug  4 2010 mike@mk-sys.cz
- fixed typo in specfile (BuildRoot)
* Mon Aug  2 2010 mike@mk-sys.cz
- create firebird user and group in preinstall script
* Sun Aug  1 2010 mike@mk-sys.cz
- update to 2.5.0.26054
* Tue Jun  1 2010 mike@mk-sys.cz
- update to 2.5.0.26038
* Wed May 12 2010 mike@mk-sys.cz
- update to 2.5.0.26005
* Fri Apr  2 2010 mike@mk-sys.cz
- update to 2.5.0.25980
* Sat Mar 20 2010 mike@mk-sys.cz
- update to 2.5.0.25958
* Sat Feb  6 2010 mike@mk-sys.cz
- update to 2.5.0.25920
* Mon Jan  4 2010 mike@mk-sys.cz
- update to 2.5.0.25904
* Sun Dec  6 2009 mike@mk-sys.cz
- update to 2.5.0.25856
* Thu Nov 12 2009 mike@mk-sys.cz
- update to 2.5.0.25784
* Wed Oct 21 2009 mike@mk-sys.cz
- update to 2.5.0.25731
* Thu Oct  8 2009 mike@mk-sys.cz
- update to 2.5.0.25725
- small fixes to files sections
* Thu Sep 24 2009 mike@mk-sys.cz
- first version of the package
